@@ -2,7 +2,6 @@ import argparse
 from typing import Optional
 
 import annoworkcli
-import annoworkcli.annofab.get_dashboard
 import annoworkcli.annofab.list_job_with_annofab_project
 import annoworkcli.annofab.list_working_hours
 import annoworkcli.annofab.put_account_external_linkage_info
@@ -16,7 +15,6 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
-    annoworkcli.annofab.get_dashboard.add_parser(subparsers)
     annoworkcli.annofab.list_job_with_annofab_project.add_parser(subparsers)
     annoworkcli.annofab.list_working_hours.add_parser(subparsers)
     annoworkcli.annofab.visualize_statistics.add_parser(subparsers)
